Jupyter Protocol |version|
==========================

This package provides the Python API for message composition relevant to Jupyter
kernels. For information related to the launch, communication and lifecycle
management of Jupyter kernels, please refer to the `Jupyter Kernel Management
documentation <https://jupyter-kernel-mgmt.readthedocs.io/en/latest/index.html>`_.

.. .. important::
   This document contains the authoritative description of the
   Jupyter messaging protocol. All developers are strongly encouraged to
   keep it updated as the implementation evolves, so that we have a single
   common reference for all protocol details.

.. note::
   The information contained in this documentation also resides in the
   `Jupyter Client documentation <https://jupyter-client.readthedocs.io/en/latest/index.html>`_.
   The documentation will be consolidated at a future date.  Please consider
   the Jupyter Client documentation as the authoritative description relative
   to the messaging protocol until further notice.

.. toctree::
   :maxdepth: 2
   :caption: User Documentation

   messaging

.. toctree::
   :maxdepth: 2
   :caption: Developer documentation

   kernels
   wrapperkernels

.. toctree::
    :maxdepth: 2
    :caption: Changes

    changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

